==> haskell-binary-conduit-1.2.5-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-conduit
version: 1.2.5
id: binary-conduit-1.2.5-1XQGZE4zXx2FjfQU0dhsBr
key: binary-conduit-1.2.5-1XQGZE4zXx2FjfQU0dhsBr
license: MIT
copyright: 2013 Alexander Vershilov
maintainer: alexander.vershilov@gmail.com
stability: Experimental
homepage: http://github.com/qnikst/binary-conduit/
synopsis: data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.
category: Conduit
author: Alexander Vershilov
exposed: True
indefinite: False
exposed-modules:
    Data.Conduit.Serialization.Binary
abi: 693d4575b216cb11d43e80e095653cd5
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/binary-conduit-1.2.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/binary-conduit-1.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/binary-conduit-1.2.5
hs-libraries: HSbinary-conduit-1.2.5-1XQGZE4zXx2FjfQU0dhsBr
depends:
    base-4.10.0.0 conduit-1.2.11-9uKDAPdSqMw2QUAecxU9lz
    bytestring-0.10.8.2 binary-0.8.5.1
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             conduit-1.2.11-9uKDAPdSqMw2QUAecxU9lz=04052e0ff779aa08eefa6f6b9de183d0
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
haddock-interfaces: /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock
haddock-html: /usr/share/doc/haskell-binary-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-conduit-1.2.5-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-binary-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-conduit
version: 1.2.5
id: binary-conduit-1.2.5-J9at1kujPf6FQI2I4RaFVg
key: binary-conduit-1.2.5-J9at1kujPf6FQI2I4RaFVg
license: MIT
copyright: 2013 Alexander Vershilov
maintainer: alexander.vershilov@gmail.com
stability: Experimental
homepage: http://github.com/qnikst/binary-conduit/
synopsis: data serialization/deserialization conduit library
description:
    The binary-conduit package.
    Allow binary serialization using iterative conduit interface.
category: Conduit
author: Alexander Vershilov
exposed: True
indefinite: False
exposed-modules:
    Data.Conduit.Serialization.Binary
abi: 288d239bb8c2c3696decee9f6c8ecf4b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/binary-conduit-1.2.5
library-dirs: /usr/lib/ghc-8.2.1/site-local/binary-conduit-1.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/binary-conduit-1.2.5
hs-libraries: HSbinary-conduit-1.2.5-J9at1kujPf6FQI2I4RaFVg
depends:
    base-4.10.0.0 conduit-1.2.12-3TKiqrYwAuWAgXZB4yMkK1
    bytestring-0.10.8.2 binary-0.8.5.1
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             conduit-1.2.12-3TKiqrYwAuWAgXZB4yMkK1=60ad65370a9da57d3d90715264a4baf8
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
haddock-interfaces: /usr/share/doc/haskell-binary-conduit/html/binary-conduit.haddock
haddock-html: /usr/share/doc/haskell-binary-conduit/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
